# Test Coverage Report: excluded packages and modules

Generated: Sun 2014-11-09 09:00 CET

These packages and modules were excluded from the coverage analysis in `django.conf.settings.COVERAGE_MODULE_EXCLUDES` or they do not contain any executable statements:

- django.contrib.admin
- django.contrib.admindocs
- django.contrib.auth
- django.contrib.contenttypes
- django.contrib.messages
- django.contrib.sessions
- django.contrib.sitemaps
- django.contrib.sites
- django.contrib.staticfiles
- django_libs
- payslip.admin
- payslip.app_settings
- payslip.fixtures
- payslip.migrations
- payslip.templatetags.__init__
- payslip.tests
- payslip.tests.test_app.__init__
- payslip.tests.test_app.models
- payslip.urls

Back to index.